# Dockerfile for Allegra on Debian Bullseye
FROM allegrapm/base:7.2
LABEL maintainer="Steinbeis GmbH & Co. KG (support@trackplus.com)"
LABEL version=7.2

ENV CONTEXT="allegra"
ENV ALLEGRA_HOME="/home/allegra"
ENV TRACKPLUS_HOME="/home/allegra"
ENV DB_URL=""
ENV DB_ADAPTER="postgresql"
ENV DB_DRIVER="org.postgresql.Driver"
ENV DB_USER="allegra"
ENV DB_PASSWD="Tissi189"
ENV JAVA_OPTS="-Djava.awt.headless=true -Xmx2048m -Xms512m -XX:MaxRAM=2500m -Duser.timezone=Europe/Berlin -XX:+UseConcMarkSweepGC"

ENV TRACKBURL=https://www.trackplus.com/files/downloads/develop-730/core
ENV TRACKURL=$TRACKBURL/allegra-latest.war
ENV TRACKVURL=$TRACKBURL/Version.properties

# Add Allegra to the container
ARG CACHEBUST=1
RUN set -ex; \
        mkdir /usr/local/tomcat/webapps-store ; \
        wget --progress=dot:giga $TRACKURL -O /usr/local/tomcat/webapps-store/allegra.war ; \
        wget --progress=dot:binary $TRACKVURL -O /tmp/Version.properties ; \
        VERSION=`grep "^version=" /tmp/Version.properties | cut -c9-`; \
        echo "Build Allegra $VERSION container" ; \
        cd /usr/local/tomcat/conf ; \
        sed -i context.xml -e "s%</Context>%<Resources cachingAllowed=\"true\" cacheMaxSize=\"100000\" /></Context>%g" ;\
	sed -i server.xml -e "s%port=\"8009\"%asyncTimeout=\"20000\" maxPostSize=\"40000000\" port=\"8009\"%g" ;\
	sed -i server.xml -e "s%connectionTimeout%asyncTimeout=\"20000\" maxPostSize=\"40000000\" connectionTimeout%g"  

# Create a context setting and startup script
RUN set -ex; \
        mkdir $ALLEGRA_HOME ;\
        TCCONF=/usr/local/tomcat/conf; \
        echo "#!/bin/bash" > $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.user = \$DB_USER\" > $ALLEGRA_HOME/Torque.properties  " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.password = \$DB_PASSWD\" >> $ALLEGRA_HOME/Torque.properties  " >> $TCCONF/entry.sh; \
        echo "echo \"torque.database.track.adapter=\$DB_ADAPTER\" >> $ALLEGRA_HOME/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.driver = \$DB_DRIVER\" >> $ALLEGRA_HOME/Torque.properties  " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.connection.url = \$DB_URL\" >> $ALLEGRA_HOME/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.factory=org.apache.torque.dsfactory.SharedPoolDataSourceFactory\" >> $ALLEGRA_HOME/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.pool.maxActive=30\" >> $ALLEGRA_HOME/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.pool.testOnBorrow=true\" >> $ALLEGRA_HOME/Torque.properties " >> $TCCONF/entry.sh; \
        echo "echo \"torque.dsfactory.track.pool.validationQuery=SELECT PKEY FROM TSTATE\" >> $ALLEGRA_HOME/Torque.properties " >> $TCCONF/entry.sh; \
        echo "env" >> $TCCONF/entry.sh; \
        echo "if [ \"\$CONTEXT\" == \"\" ]; then " >> $TCCONF/entry.sh; \
        echo "  CONTEXT=allegra"  >> $TCCONF/entry.sh; \
        echo "fi " >> $TCCONF/entry.sh; \
        echo "TCBASE=/usr/local/tomcat"  >> $TCCONF/entry.sh; \
        echo "mkdir -p \$TCBASE/conf/Catalina/localhost " >> $TCCONF/entry.sh; \
        contexts="<Context path=\\\"/\$CONTEXT\\\" docBase=\\\"\$TCBASE/webapps-store/allegra.war\\\"/> " ; \
        echo "echo \"$contexts\" > \$TCBASE/conf/Catalina/localhost/\$CONTEXT.xml " >> $TCCONF/entry.sh; \
        echo "echo \"Using context \$CONTEXT\" " >> $TCCONF/entry.sh; \
        echo "cd /usr/local/tomcat/bin; ./catalina.sh run" >> $TCCONF/entry.sh; \
	# echo "until nc -z -v -w30 $CFG_MYSQL_HOST 3306" >> $TCCONF/entry.sh; \
	# echo "do" >> $TCCONF/entry.sh; \
	# echo "  echo 'Waiting for database connection...'" >> $TCCONF/entry.sh; \
	# echo "  sleep 5 " >> $TCCONF/entry.sh; \
	# echo "done " >> $TCCONF/entry.sh; \
        chmod 755 $TCCONF/entry.sh

RUN echo "Downloading Apereo CAS from Allegra server"; \
	cd /usr/local/tomcat/webapps; \
	wget https://trackplus.com/files/downloads/latest-dist/cas/cas.war; \
	mv cas.war sso.war

CMD [ "/bin/bash", "-c", "cd /opt/allegra-print-server/ && ./startStop.sh start && /usr/local/tomcat/conf/entry.sh" ]
