# Quick reference

-	**Maintained by**:  
	[Steinbeis GmbH & Co. KG](https://www.trackplus.com)

-	**Where to get help**:  
	[Allegra Support](https://www.trackplus.com/en/service/service.html)

# Supported tags and respective `Dockerfile` links

-	[`7.2`](https://www.trackplus.com/en/service/download.html)

# Quick reference (cont.)

-	**Where to file issues**:  
	[https://www.trackplus.com/track](https://www.trackplus.com/track)

-	**Supported architectures**: ([more info](https://github.com/docker-library/official-images#architectures-other-than-amd64))  
	[`amd64`](https://hub.docker.com/r/amd64/postgres/)


# What is Allegra?

Allegra is a web-based software for project management, task management, and service management. 
Small teams with few projects use Allegra as well as companies with thousands of users. Allegra 
supports classic project management methods, agile methods, and hybrid project management.

Allegra is suitable for:

* Agile and traditional project management
* Simple to complex task management
* Service portal and ticket system
* Workflow automation
* Quality management
* Requirements management

![logo](https://www.trackplus.com/files/images/logos/allegra-logo-309x70.png)


# How to use this image

To be operational, Allegra needs 

* access to a relational database management system (RDBMS) like MS SQLServer or PostgreSQL
* access to a file system for attachment storage and configuration files. 

Environment variables are being used to configure
these settings.

**Note**: Before you start the Allegra image for the first time
you must have created a new,
empty database and tell Allegra how to connect to it.

## Tomcat Servlet Container

The Allegra image builds upon an Apache Tomcat 9 servlet container
running on an OpenJDK JDK 11 Java system (`9.0-jdk11-openjdk-bullseye`). 
Internally Tomcat offers its service on port 8080, which you can map 
externally to another port.

**Note**: Before you start the Allegra image for the first time
you must have created a new,
empty database and tell Allegra how to connect to it.

## Example Step 1: Setting up a Docker Network

We create a Docker network to connect the Allegra image with
the Docker database container.

```console
$ docker network create dbbus-demo
```
## Example Step 2: Setting up a PostgreSQL Database

We create a PostgreSQL database named `postgres-demo` connected
to the network defined previously.

```console
$ docker run --name postgres-demo --network dbbus-demo \
       --restart always \
       -e POSTGRES_DB="postgres-demo" \
       -e POSTGRES_USER=someUser \
       -e POSTGRES_PASSWORD=somePassword \
       -d postgres:13-bullseye 
```
## Example Step 3: Setting up an Allegra Instance

Here we configure and launch a fresh Allegra instance connected
to the previously configured database. we have mapped the
HTTP port to 8888 and the AJP port to 8889. The attachments
and configuration files will be accessible from the host
computer at `/home/allegra/demo`.

```console
$ HTTP_PORT=8888
$ AJP_PORT=8889
$ docker run --detach --name allegra-demo --network dbbus-demo \
       --restart always \
       -e JAVA_OPTS="-Djava.awt.headless=true -Xmx1024m -Xms512m" \
       -e CONTEXT=demo \
       -e DB_URL="jdbc:postgresql://postgres-demo/postgres-demo" \
       -e DB_USER=someUser \
       -e DB_PASSWD=somePassword \
       -p $HTTP_PORT:8080 \
       -p $AJP_PORT:8009 \
       --mount type=bind,source="/home/allegra/demo",target=/home/allegra \
       -v /tmp:/backup \
       allegrapm/core:7.2
```


## Environment Variables

The Allegra image uses several environment variables to provision a database
connection and define a file storage location for persisting attachments
and configuration files.


### `CONTEXT`

The `CONTEXT`environment variable determines the URL, under which the Allegra instance
will be visible. The URL will look like `http://<yourmachine>:8080/$CONTEXT`, assuming
you have mapped port 8080 of the container to 8080 outside of your container.
The default value is `allegra`.


### `DB_URL`

This defines the JDBC driver URL under which Allegra can find the database.
This database has to exist before you start Allegra.
The user defined by `DB_USER`and password `DB_PASSWD` should have 
been granted all permissions to this database. 

Here are some `DB_URL` examples:

* PostgreSQL: `jdbc:postgresql://yourdbserver/allegra`
* MySQL: `jdbc:mysql://localhost:3306/allegra?useSSL=false&useUnicode=true&characterEncoding=UTF-8&zeroDateTimeBehavior=convertToNull&serverTimezone=UTC`
* Oracle: `jdbc:oracle:thin:@80.96.67.62:1521:orcl`
* Microsoft SQLServer: `jdbc:jtds:sqlserver://localhost/allegra`
* Firebird: `jdbc:firebirdsql://localhost/home/allegra/dbase/ALLEGRA.GDB?charSet=UTF-8`
* DB2: `jdbc:db2:ALLEGRA`

### `DB_ADAPTER`

To connect to a database Allegra needs to know its type. The following types
are supported by this image:

* postgresql
* mysql
* mssql
* oracle (with additional library)
* firebird
* db2app (with additional library)

Oracle and DB2 databases need additional JDBC drivers that do not come with
this image. See [Adding JDBC Drivers](#Adding-JDBC-Drivers) for more information.

The default database system being used is **PostgreSQL**.

### `DB_DRIVER`

With this variable you define the JDBC driver class to be used. It depends
on the type  of database you want to use (`DB_ADAPTER`).

The default is `org.postgresql.Driver` for a PostgreSQL database.

Other examples are:

* MySQL: `org.gjt.mm.mysql.Driver`
* Oracle: `oracle.jdbc.driver.OracleDriver`
* Microsoft SQLServer: `net.sourceforge.jtds.jdbc.Driver`
* Firebird: `org.firebirdsql.jdbc.FBDriver`
* DB2: `com.ibm.db2.jdbc.app.DB2Driver`

### `DB_USER`

`DB_USER` defines the user under which Allegra accesses the database.
The default value is "allegra".

### `DB_PASSWD`

`DB_PASSWD` defines the password for the user under which Allegra accesses the database.

The default value is "Tissi189"

### `JAVA_OPTS`

The `JAVA_OPTS`are handed over to the Allegra/Tomcat virtual machine. Here
you can set the memory available to your  Allegra instance. Example and
default:

`-Djava.awt.headless=true -Xmx2048m -Xms512m -XX:MaxRAM=2500m -Duser.timezone=Europe/Berlin`

## Adding JDBC Drivers

We recommend to add additional JDBC drivers by creating a new Docker
image based on the Allegra image. The libraries should be placed under
